@@ -142,9 +142,15 @@ def create_tables():
         """)
 
     con.execute(
-        """
+        sa.text("""
         CREATE OR REPLACE VIEW impact_comb AS (
-            WITH TMP AS (
+             SELECT start_time as kill_timestamp,
+                    killer_name, killer_type, killer as killer_id,
+                    target_name, target_type, target as target_id,
+                    weapon_name, weapon_type, weapon as weapon_id,
+                    impact_dist, impact_id,
+                    weapon_first_time, weapon_last_time
+                FROM  (
                 SELECT
                     id as impact_id, impact_dist,
                     killer, killer_name, killer_type,
@@ -165,15 +171,7 @@ def create_tables():
                 WHERE killer IS NOT NULL AND
                     target IS NOT NULL AND weapon IS NOT NULL
                     AND impact_dist < 10
-            ),
-            TMP2 as (
-                SELECT start_time as kill_timestamp,
-                    killer_name, killer_type, killer as killer_id,
-                    target_name, target_type, target as target_id,
-                    weapon_name, weapon_type, weapon as weapon_id,
-                    impact_dist, impact_id,
-                    weapon_first_time, weapon_last_time
-                FROM tmp t
+            ) t
                 INNER JOIN (SELECT id as weapon,
                             first_seen as weapon_first_time,
                             last_seen AS weapon_last_time
@@ -187,9 +185,8 @@ def create_tables():
                 LEFT JOIN (SELECT name AS weapon_name, category AS weapon_type
                             FROM weapon_types) weap_type
                 USING (weapon_name)
-            )
-            SELECT * FROM tmp2)
-        """)
+        )
+        """))
     con.close()
     print("All tables and views created successfully!")
 
